=======
History
=======

0.1.0
------------------

* First release on PyPI.

1.0.0
------------------
Fixed an issue with the parser not handling the baseExtension
element contents correctly (eventDeclarations and eventID).

2.0.0
-----

Added the FlexibleNSParser to deal with explicit namespace declarations in
EPCIS XML documents in the main EPCIS namespace.

2.0.1
-----

Removed some debug logging commands that could throw exceptions.
